@@ -423,21 +423,19 @@ class VirtualService(HttpClient, KempBaseObjectModel):
         """RealServer factory with pre-configured LoadMaster connection."""
         return RealServer(self.get_virtual_service_info, ip, port)
 
-    def get_real_server(self, index=None, address=None, port=None,
-                        protocol=None, real_server_address=None,
-                        real_server_port=None):
-        if index is None:
+    def get_real_server(self, real_server_address=None, real_server_port=None):
+        if self.index is None:
             server_id = {
-                "vs": address,
-                "port": port,
-                "prot": protocol,
+                "vs": self.vs,
+                "port": self.port,
+                "prot": self.prot,
                 "rs": real_server_address,
                 "rsport": real_server_port,
             }
             response = self._get("/showrs", server_id)
         else:
             server_id = {
-                "vs": index,
+                "vs": self.index,
                 "rs": real_server_address,
                 "rsport": real_server_port,
             }
